pub struct ResolvedPlugin { /* private fields */ }Expand description
An inert plugin descriptor whose resources retain their source authority.
Implementations
Sourceimpl ResolvedPlugin
impl ResolvedPlugin
Sourcepub fn from_environment(
selected_root_id: String,
environment_id: String,
root: PathUri,
manifest_path: PathUri,
manifest: PluginManifest<PathUri>,
) -> Result<Self, ResolvedPluginError>
pub fn from_environment( selected_root_id: String, environment_id: String, root: PathUri, manifest_path: PathUri, manifest: PluginManifest<PathUri>, ) -> Result<Self, ResolvedPluginError>
Creates an environment-owned descriptor from a validated plugin manifest.
Sourcepub fn selected_root_id(&self) -> &str
pub fn selected_root_id(&self) -> &str
Returns the opaque ID supplied for the selected capability root.
Sourcepub fn location(&self) -> &ResolvedPluginLocation
pub fn location(&self) -> &ResolvedPluginLocation
Returns the authority-bound package location.
Sourcepub fn manifest_path(&self) -> &PluginResourceLocator
pub fn manifest_path(&self) -> &PluginResourceLocator
Returns the manifest resource used to resolve this package.
Sourcepub fn manifest(&self) -> &PluginManifest<PluginResourceLocator>
pub fn manifest(&self) -> &PluginManifest<PluginResourceLocator>
Returns package metadata whose resource fields retain their source authority.